import { displayNumber } from '../../util/helpers.js';

export class Table {
  constructor(box) {
    this.box = box;
    this.columns = [];
    this.rows = [];
    this.table = box.el.appendChild(document.createElement('table'));
    this.headings = this.table.appendChild(document.createElement('tr'));
  }

  setColumns(columns) {
    if (JSON.stringify(columns) === JSON.stringify(this.columns)) {
      return;
    }
    if (this.columns.length) {
      this.table.innerHTML = '';
      this.headings = this.table.appendChild(document.createElement('tr'));
      this.columns = [];
    }
    this.columns = columns;
    for (const { title } of columns) {
      const heading = document.createElement('th');
      this.headings.appendChild(heading);
      heading.innerHTML = title ?? '';
    }
    if (this.rows.length) {
      const { rows } = this;
      this.rows = [];
      for (const row of rows) {
        this.addRow(row);
      }
    }
  }

  addRow(rowMap) {
    this.rows.push(rowMap);
    const row = this.table.appendChild(document.createElement('tr'));
    for (const { key } of this.columns) {
      const value = rowMap.get(key);
      const cell = row.appendChild(document.createElement('td'));
      cell.innerHTML = typeof value === 'number' ? displayNumber(value) : value ?? '';
    }
  }

  listUniqueValueKeys() {
    return this.columns; // TODO
  }
}
